@@ -3,7 +3,7 @@ package CPAN::Plugin::Sysdeps::Mapping;
 use strict;
 use warnings;
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 # shortcuts
 #  os and distros
@@ -194,6 +194,12 @@ sub mapping {
       [like_debian,
        [package => 'libsamplerate0-dev']]],
 
+     [cpanmod => 'Audio::Ofa',
+      [os_freebsd,
+       [package => 'libofa']],
+      [like_debian,
+       [package => 'libofa0-dev']]],
+
      [cpanmod => 'Audio::Opusfile',
       [os_freebsd,
        [package => 'opusfile']],
@@ -351,7 +357,12 @@ sub mapping {
       [like_debian,
        [linuxdistrocodename => 'squeeze',
 	[package => 'libgmp3-dev']],
-       [package => 'libgmp-dev']]],
+       [package => 'libgmp-dev']],
+      ## Does not work: "Symbol not found: ___gmp_randclear"
+      ## Same problem with homebrew/versions/gmp4
+      #[os_darwin,
+      # [package => 'gmp']]
+     ],
 
      [cpanmod => 'Crypt::GCrypt',
       [os_freebsd,
@@ -442,7 +453,11 @@ sub mapping {
       [os_freebsd,
        [package => 'mpfr']],
       [like_debian,
-       [package => 'libmpfr-dev']]],
+       [package => 'libmpfr-dev']],
+      ## Does not work:
+      #[os_darwin,
+      # [package => 'mpfr']],
+     ],
 
      [cpanmod => 'DB_File',
       [like_debian,
@@ -751,6 +766,12 @@ sub mapping {
       [like_debian,
        [package => 'libgtk2.0-dev']]],
 
+     [cpanmod => 'Gtk2::ImageView',
+      [os_freebsd,
+       [package => 'gtkimageview']],
+      [like_debian,
+       [package => 'libgtkimageview-dev']]],
+
      [cpanmod => 'Gtk3',
       [os_freebsd,
        # additionally dbus has to be enabled and started
@@ -995,6 +1016,10 @@ sub mapping {
       [like_debian,
        [package => 'libc6-dev']]],
 
+     [cpanmod => 'Linux::Netfilter::Log',
+      [like_debian,
+       [package => 'libnetfilter-log-dev']]],
+
      [cpanmod => 'Linux::Prctl',
       [like_debian,
        [package => 'libcap-dev']]],
@@ -1596,7 +1621,9 @@ sub mapping {
        [package => 'libstatgrab']],
       [like_debian,
        # unfortunately does not work in wheezy, the library version is too old for the module
-       [package => 'libstatgrab-dev']]],
+       [package => 'libstatgrab-dev']],
+      [os_darwin,
+       [package => 'libstatgrab']]],
 
      [cpanmod => 'URPM',
       [like_debian,
